attrs = dataRecord.getDataAttributes();
diff --git a/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/src/com/raytheon/uf/common/dataplugin/satellite/units/goes/PercentOfNormalTPWPixel.java b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/src/com/raytheon/uf/common/dataplugin/satellite/units/goes/PercentOfNormalTPWPixel.java
index 756d5d899d..feb3948edd 100644
--- a/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/src/com/raytheon/uf/common/dataplugin/satellite/units/goes/PercentOfNormalTPWPixel.java
+++ b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/src/com/raytheon/uf/common/dataplugin/satellite/units/goes/PercentOfNormalTPWPixel.java
@@ -25,19 +25,19 @@ import javax.measure.unit.Unit;
import org.apache.commons.lang.builder.HashCodeBuilder;
-import com.raytheon.uf.common.dataplugin.satellite.units.generic.GenericPixel;
import com.raytheon.uf.common.dataplugin.satellite.units.goes.convert.PixelToPercentConverter;
/**
- * TODO Add Description
+ * A unit for the percent of normal total precipitable water pixels.
*
*
*
* SOFTWARE HISTORY
*
- * Date Ticket# Engineer Description
- * ------------ ---------- ----------- --------------------------
- * May 12, 2010 jsanchez Initial creation
+ * Date Ticket# Engineer Description
+ * ------------- -------- ----------- --------------------------
+ * May 12, 2010 jsanchez Initial creation
+ * Apr 15, 2014 2947 bsteffen Fix equals.
*
*
*
@@ -50,7 +50,7 @@ public class PercentOfNormalTPWPixel extends Unit {
@Override
public boolean equals(Object anObject) {
- return (anObject instanceof GenericPixel);
+ return (anObject instanceof PercentOfNormalTPWPixel);
}
@Override
diff --git a/edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/poesDif11u3_7uIR.xml b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/poesDif11u3_7uIR.xml
similarity index 82%
rename from edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/poesDif11u3_7uIR.xml
rename to edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/poesDif11u3_7uIR.xml
index fe5430b7c2..63d336de85 100644
--- a/edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/poesDif11u3_7uIR.xml
+++ b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/poesDif11u3_7uIR.xml
@@ -18,9 +18,9 @@
See_the_AWIPS_II_Master_Rights_File_("Master_Rights_File.pdf")_for
further_licensing_information.
-->
-
+
-
-
+
+
diff --git a/edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/satDif11u12uIR.xml b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/satDif11u12uIR.xml
similarity index 80%
rename from edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/satDif11u12uIR.xml
rename to edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/satDif11u12uIR.xml
index f200245d78..e2607addb8 100644
--- a/edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/satDif11u12uIR.xml
+++ b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/satDif11u12uIR.xml
@@ -18,9 +18,9 @@
See_the_AWIPS_II_Master_Rights_File_("Master_Rights_File.pdf")_for
further_licensing_information.
-->
-
+
-
-
+
+
diff --git a/edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/satDif11u13uIR.xml b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/satDif11u13uIR.xml
similarity index 79%
rename from edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/satDif11u13uIR.xml
rename to edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/satDif11u13uIR.xml
index cefc67320c..f31c3ef789 100644
--- a/edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/satDif11u13uIR.xml
+++ b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/satDif11u13uIR.xml
@@ -18,9 +18,9 @@
See_the_AWIPS_II_Master_Rights_File_("Master_Rights_File.pdf")_for
further_licensing_information.
-->
-
+
-
-
+
+
\ No newline at end of file
diff --git a/edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/satDif11u3_9uIR.xml b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/satDif11u3_9uIR.xml
similarity index 79%
rename from edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/satDif11u3_9uIR.xml
rename to edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/satDif11u3_9uIR.xml
index e5c254bf89..4ae657a5fd 100644
--- a/edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/satDif11u3_9uIR.xml
+++ b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/satDif11u3_9uIR.xml
@@ -18,9 +18,9 @@
See_the_AWIPS_II_Master_Rights_File_("Master_Rights_File.pdf")_for
further_licensing_information.
-->
-
+
-
-
+
+
diff --git a/edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/satDivWVIR.xml b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/satDivWVIR.xml
similarity index 80%
rename from edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/satDivWVIR.xml
rename to edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/satDivWVIR.xml
index 02131c35f1..7f9d5c9c1c 100644
--- a/edexOsgi/com.raytheon.uf.common.derivparam/utility/common_static/base/derivedParameters/definitions/satDivWVIR.xml
+++ b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/definitions/satDivWVIR.xml
@@ -18,9 +18,9 @@
See_the_AWIPS_II_Master_Rights_File_("Master_Rights_File.pdf")_for
further_licensing_information.
-->
-
+
-
-
+
+
diff --git a/edexOsgi/com.raytheon.uf.common.derivparam.python/utility/common_static/base/derivedParameters/functions/satDif11u3_9uIR.py b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/functions/satDif11u3_9uIR.py
similarity index 100%
rename from edexOsgi/com.raytheon.uf.common.derivparam.python/utility/common_static/base/derivedParameters/functions/satDif11u3_9uIR.py
rename to edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/functions/satDif11u3_9uIR.py
diff --git a/edexOsgi/com.raytheon.uf.common.derivparam.python/utility/common_static/base/derivedParameters/functions/satDifference.py b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/functions/satDifference.py
similarity index 100%
rename from edexOsgi/com.raytheon.uf.common.derivparam.python/utility/common_static/base/derivedParameters/functions/satDifference.py
rename to edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/functions/satDifference.py
diff --git a/edexOsgi/com.raytheon.uf.common.derivparam.python/utility/common_static/base/derivedParameters/functions/satDivWVIR.py b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/functions/satDivWVIR.py
similarity index 100%
rename from edexOsgi/com.raytheon.uf.common.derivparam.python/utility/common_static/base/derivedParameters/functions/satDivWVIR.py
rename to edexOsgi/com.raytheon.uf.common.dataplugin.satellite/utility/common_static/base/derivedParameters/functions/satDivWVIR.py
diff --git a/edexOsgi/com.raytheon.uf.common.dataplugin/src/com/raytheon/uf/common/dataplugin/PluginDataObject.java b/edexOsgi/com.raytheon.uf.common.dataplugin/src/com/raytheon/uf/common/dataplugin/PluginDataObject.java
index 6d624ee83b..be6d7d5a72 100644
--- a/edexOsgi/com.raytheon.uf.common.dataplugin/src/com/raytheon/uf/common/dataplugin/PluginDataObject.java
+++ b/edexOsgi/com.raytheon.uf.common.dataplugin/src/com/raytheon/uf/common/dataplugin/PluginDataObject.java
@@ -104,6 +104,8 @@ import com.raytheon.uf.common.time.DataTime;
* PluginDataObject.
* May 16, 2013 1869 bsteffen Rewrite dataURI property mappings.
* Aug 30, 2013 2298 rjpeter Make getPluginName abstract
+ * Apr 15, 2014 1869 bsteffen Remove unused transient record field.
+ *
*
*
*/
@@ -173,9 +175,6 @@ public abstract class PluginDataObject extends PersistableDataObject implements
@Transient
private transient int uriIndex = 2;
- @Transient
- private Object record = null;
-
/**
* Default Constructor
*/
@@ -271,14 +270,6 @@ public abstract class PluginDataObject extends PersistableDataObject implements
}
}
- public Object getRecord() {
- return record;
- }
-
- public void setRecord(Object record) {
- this.record = record;
- }
-
/**
* TODO: Rework non-PointDataContainer plots and remove
*
diff --git a/ncep/gov.noaa.nws.ncep.viz.rsc.satellite/src/gov/noaa/nws/ncep/viz/rsc/satellite/area/McIdasAreaProviderFactory.java b/ncep/gov.noaa.nws.ncep.viz.rsc.satellite/src/gov/noaa/nws/ncep/viz/rsc/satellite/area/McIdasAreaProviderFactory.java
index a294de8723..a1e7c55f14 100644
--- a/ncep/gov.noaa.nws.ncep.viz.rsc.satellite/src/gov/noaa/nws/ncep/viz/rsc/satellite/area/McIdasAreaProviderFactory.java
+++ b/ncep/gov.noaa.nws.ncep.viz.rsc.satellite/src/gov/noaa/nws/ncep/viz/rsc/satellite/area/McIdasAreaProviderFactory.java
@@ -30,7 +30,6 @@ import com.raytheon.uf.viz.core.exception.VizException;
import com.raytheon.uf.viz.core.requests.ThriftClient;
import com.raytheon.uf.viz.core.rsc.AbstractRequestableResourceData;
import com.raytheon.uf.viz.core.rsc.ResourceType;
-import com.raytheon.viz.satellite.SatelliteDataCubeAdapter;
import com.vividsolutions.jts.geom.Polygon;
import gov.noaa.nws.ncep.common.dataplugin.mcidas.McidasMapCoverage;
diff --git a/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/src/com/raytheon/uf/common/dataplugin/satellite/units/SatelliteUnits.java b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/src/com/raytheon/uf/common/dataplugin/satellite/units/SatelliteUnits.java
index 07bc09ed35..4d0d7d8ef3 100644
--- a/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/src/com/raytheon/uf/common/dataplugin/satellite/units/SatelliteUnits.java
+++ b/edexOsgi/com.raytheon.uf.common.dataplugin.satellite/src/com/raytheon/uf/common/dataplugin/satellite/units/SatelliteUnits.java
@@ -28,6 +28,7 @@ import javax.measure.unit.SI;
import javax.measure.unit.Unit;
import javax.measure.unit.UnitFormat;
+import com.raytheon.uf.common.dataplugin.satellite.units.counts.DerivedWVPixel;
import com.raytheon.uf.common.dataplugin.satellite.units.generic.GenericPixel;
import com.raytheon.uf.common.dataplugin.satellite.units.goes.PercentOfNormalTPWPixel;
import com.raytheon.uf.common.dataplugin.satellite.units.goes.PolarPrecipWaterPixel;
@@ -45,12 +46,14 @@ import com.raytheon.uf.common.dataplugin.satellite.units.water.RainfallRatePixel
*
*
* SOFTWARE HISTORY
* Date Ticket# Engineer Description
* ------------ ---------- ----------- --------------------------
* Sep 4, 2007 njensen Initial creation
* Mar 23, 2009 2086 jsanchez Updated RainfallRatePixel to be velocity.
* Added PolarPrecipWaterPixel.
* Jun 20, 2013 2122 mschenke Added alias for degrees celsius to "C"
*
*
*
@@ -84,35 +87,35 @@ public class SatelliteUnits {
public static final Unit GENERIC_PIXEL = new GenericPixel();
+ public static final Unit DERIVED_WV = new DerivedWVPixel();
+
public static void register() {
- UnitFormat.getUCUMInstance().alias(SI.KELVIN, "kelvin");
- UnitFormat.getUCUMInstance().alias(SI.CELSIUS, "C");
- UnitFormat.getUCUMInstance().label(SatelliteUnits.IR_PIXEL, "IRPixel");
- UnitFormat.getUCUMInstance().label(SatelliteUnits.PRECIP_PIXEL,
- "PrecipPixel");
- UnitFormat.getUCUMInstance().label(SatelliteUnits.RAINFALL_RATE_PIXEL,
- "RainfallRatePixel");
- UnitFormat.getUCUMInstance().label(
- SatelliteUnits.SOUNDER_CLOUD_AMOUNT_PIXEL,
+ register(UnitFormat.getUCUMInstance());
+ register(UnitFormat.getInstance());
+
+ }
+
+ public static void register(UnitFormat format) {
+ format.alias(SI.KELVIN, "kelvin");
+ format.alias(SI.CELSIUS, "C");
+ format.label(SatelliteUnits.IR_PIXEL, "IRPixel");
+ format.label(SatelliteUnits.PRECIP_PIXEL, "PrecipPixel");
+ format.label(SatelliteUnits.RAINFALL_RATE_PIXEL, "RainfallRatePixel");
+ format.label(SatelliteUnits.SOUNDER_CLOUD_AMOUNT_PIXEL,
"SounderCloudAmountPixel");
- UnitFormat.getUCUMInstance().label(
- SatelliteUnits.SOUNDER_CLOUD_HEIGHT_PIXEL,
+ format.label(SatelliteUnits.SOUNDER_CLOUD_HEIGHT_PIXEL,
"SounderCloudTopHeightPixel");
- UnitFormat.getUCUMInstance().label(
- SatelliteUnits.SOUNDER_LIFTED_INDEX_PIXEL,
+ format.label(SatelliteUnits.SOUNDER_LIFTED_INDEX_PIXEL,
"SounderLiftedIndexPixel");
- UnitFormat.getUCUMInstance().label(
- SatelliteUnits.SOUNDER_PRECIP_WATER_PIXEL,
+ format.label(SatelliteUnits.SOUNDER_PRECIP_WATER_PIXEL,
"SounderPrecipWaterPixel");
- UnitFormat.getUCUMInstance().label(
- SatelliteUnits.POLAR_PRECIP_WATER_PIXEL,
+ format.label(SatelliteUnits.POLAR_PRECIP_WATER_PIXEL,
"PolarPrecipWaterPixel");
- UnitFormat.getUCUMInstance().label(
- SatelliteUnits.SOUNDER_SKIN_TEMP_PIXEL, "SounderSkinTempPixel");
- UnitFormat.getUCUMInstance().label(SatelliteUnits.GENERIC_PIXEL,
- "GenericPixel");
- UnitFormat.getUCUMInstance().label(SatelliteUnits.PERCENT_PIXEL,
- "PercentOfNormalTPWPixel");
+ format.label(SatelliteUnits.SOUNDER_SKIN_TEMP_PIXEL,
+ "SounderSkinTempPixel");
+ format.label(SatelliteUnits.GENERIC_PIXEL, "GenericPixel");
+ format.label(SatelliteUnits.PERCENT_PIXEL, "PercentOfNormalTPWPixel");
+ format.label(SatelliteUnits.DERIVED_WV, "DerivedWV");
}
}
@@ -45,12 +46,14 @@ import com.raytheon.uf.common.dataplugin.satellite.units.water.RainfallRatePixel
*
* SOFTWARE HISTORY
- * Date Ticket# Engineer Description
- * ------------ ---------- ----------- --------------------------
- * Sep 4, 2007 njensen Initial creation
- * Mar 23, 2009 2086 jsanchez Updated RainfallRatePixel to be velocity.
- * Added PolarPrecipWaterPixel.
- * Jun 20, 2013 2122 mschenke Added alias for degrees celsius to "C"
+ * Date Ticket# Engineer Description
+ * ------------- -------- ----------- --------------------------
+ * Sep 04, 2007 njensen Initial creation
+ * Mar 23, 2009 2086 jsanchez Updated RainfallRatePixel to be velocity.
+ * Added PolarPrecipWaterPixel.
+ * Jun 20, 2013 2122 mschenke Added alias for degrees celsius to "C"
+ * Apr 15, 2014 2947 bsteffen Register units with both formats.
+ *
*
*